==> cloudwatch-1.115.0-sources.jar: software/amazon/awscdk/services/cloudwatch/AlarmRule.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Class with static functions to build AlarmRule for Composite Alarms.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T15:55:57.887Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.AlarmRule")
public class AlarmRule extends software.amazon.jsii.JsiiObject {

    protected AlarmRule(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AlarmRule(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public AlarmRule() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * function to join all provided AlarmRules with AND operator.
     * <p>
     * @param operands IAlarmRules to be joined with AND operator. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule allOf(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule... operands) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "allOf", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), java.util.Arrays.<Object>stream(operands).toArray(Object[]::new));
    }

    /**
     * function to join all provided AlarmRules with OR operator.
     * <p>
     * @param operands IAlarmRules to be joined with OR operator. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule anyOf(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule... operands) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "anyOf", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), java.util.Arrays.<Object>stream(operands).toArray(Object[]::new));
    }

    /**
     * function to build Rule Expression for given IAlarm and AlarmState.
     * <p>
     * @param alarm IAlarm to be used in Rule Expression. This parameter is required.
     * @param alarmState AlarmState to be used in Rule Expression. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule fromAlarm(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarm alarm, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.AlarmState alarmState) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "fromAlarm", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), new Object[] { java.util.Objects.requireNonNull(alarm, "alarm is required"), java.util.Objects.requireNonNull(alarmState, "alarmState is required") });
    }

    /**
     * function to build TRUE/FALSE intent for Rule Expression.
     * <p>
     * @param value boolean value to be used in rule expression. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule fromBoolean(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "fromBoolean", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * function to build Rule Expression for given Alarm Rule string.
     * <p>
     * @param alarmRule string to be used in Rule Expression. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule fromString(final @org.jetbrains.annotations.NotNull java.lang.String alarmRule) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "fromString", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), new Object[] { java.util.Objects.requireNonNull(alarmRule, "alarmRule is required") });
    }

    /**
     * function to wrap provided AlarmRule in NOT operator.
     * <p>
     * @param operand IAlarmRule to be wrapped in NOT operator. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule not(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule operand) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "not", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), new Object[] { java.util.Objects.requireNonNull(operand, "operand is required") });
    }
}

==> cloudwatch-1.173.0-sources.jar: software/amazon/awscdk/services/cloudwatch/AlarmRule.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Class with static functions to build AlarmRule for Composite Alarms.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Alarm alarm1;
 * Alarm alarm2;
 * Alarm alarm3;
 * Alarm alarm4;
 * IAlarmRule alarmRule = AlarmRule.anyOf(AlarmRule.allOf(AlarmRule.anyOf(alarm1, AlarmRule.fromAlarm(alarm2, AlarmState.OK), alarm3), AlarmRule.not(AlarmRule.fromAlarm(alarm4, AlarmState.INSUFFICIENT_DATA))), AlarmRule.fromBoolean(false));
 * CompositeAlarm.Builder.create(this, "MyAwesomeCompositeAlarm")
 *         .alarmRule(alarmRule)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:27.161Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.AlarmRule")
public class AlarmRule extends software.amazon.jsii.JsiiObject {

    protected AlarmRule(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AlarmRule(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public AlarmRule() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * function to join all provided AlarmRules with AND operator.
     * <p>
     * @param operands IAlarmRules to be joined with AND operator. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule allOf(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule... operands) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "allOf", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), java.util.Arrays.<Object>stream(operands).toArray(Object[]::new));
    }

    /**
     * function to join all provided AlarmRules with OR operator.
     * <p>
     * @param operands IAlarmRules to be joined with OR operator. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule anyOf(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule... operands) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "anyOf", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), java.util.Arrays.<Object>stream(operands).toArray(Object[]::new));
    }

    /**
     * function to build Rule Expression for given IAlarm and AlarmState.
     * <p>
     * @param alarm IAlarm to be used in Rule Expression. This parameter is required.
     * @param alarmState AlarmState to be used in Rule Expression. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule fromAlarm(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarm alarm, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.AlarmState alarmState) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "fromAlarm", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), new Object[] { java.util.Objects.requireNonNull(alarm, "alarm is required"), java.util.Objects.requireNonNull(alarmState, "alarmState is required") });
    }

    /**
     * function to build TRUE/FALSE intent for Rule Expression.
     * <p>
     * @param value boolean value to be used in rule expression. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule fromBoolean(final @org.jetbrains.annotations.NotNull java.lang.Boolean value) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "fromBoolean", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * function to build Rule Expression for given Alarm Rule string.
     * <p>
     * @param alarmRule string to be used in Rule Expression. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule fromString(final @org.jetbrains.annotations.NotNull java.lang.String alarmRule) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "fromString", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), new Object[] { java.util.Objects.requireNonNull(alarmRule, "alarmRule is required") });
    }

    /**
     * function to wrap provided AlarmRule in NOT operator.
     * <p>
     * @param operand IAlarmRule to be wrapped in NOT operator. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule not(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudwatch.IAlarmRule operand) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudwatch.AlarmRule.class, "not", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarmRule.class), new Object[] { java.util.Objects.requireNonNull(operand, "operand is required") });
    }
}
